lilypondfiletools.MIDIBlock
===========================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.lilypond_format

    Inherited from :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.is_formatted_when_empty

    Inherited from :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock>`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__repr__

    Inherited from :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock>`
